@@ -114,8 +114,14 @@
 # define USE_ON_EXIT_FOR_ATEXIT
 # endif
 
+# define PREFER_MMAP_LARGE_BLOCKS
+
 # define FMOD_CAN_RETURN_POS_ZERO
 
+# ifdef _POSIX_PTHREAD_SEMANTICS
+#  define SUBPROCESS_USE_FORK1
+# endif
+
 # ifdef i386
 #  define MZ_USE_JIT_I386
 #  define MZ_JIT_USE_MPROTECT
@@ -156,39 +162,49 @@
 
 #if defined(linux)
 
+# ifdef __ANDROID__
+#  define SPLS_LINUX "android"
+# else
+#  define SPLS_LINUX "linux"
+# endif
+
 # if defined(i386)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "i386-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "i386-"SPLS_LINUX
 #  define REGISTER_POOR_MACHINE
 #  define MZ_TRY_EXTFLONUMS
 #  define ASM_DBLPREC_CONTROL_87
 # endif
 # if defined(powerpc)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "ppc-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "ppc-"SPLS_LINUX
 # endif
 # if defined(__mc68000__)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "m68k-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "m68k-"SPLS_LINUX
 # endif
 # if defined(mips)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "mips-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "mips-"SPLS_LINUX
 # endif
 # if defined(__alpha__)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "alpha-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "alpha-"SPLS_LINUX
 # endif
 # if defined(__hppa__)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "hppa-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "hppa-"SPLS_LINUX
 # endif
 # if defined(__sparc__)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "sparc-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "sparc-"SPLS_LINUX
 #  define FLUSH_SPARC_REGISTER_WINDOWS
 # endif
+# if defined(__arm__) || defined(__thumb__)
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "arm-"SPLS_LINUX
+#  define FFI_CALLBACK_NEED_INT_CLEAR
+# endif
 # if defined(__x86_64__)
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "x86_64-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "x86_64-"SPLS_LINUX
 #  define REGISTER_POOR_MACHINE
 #  define ASM_DBLPREC_CONTROL_87
 #  define MZ_TRY_EXTFLONUMS
 # endif
 # ifndef SCHEME_PLATFORM_LIBRARY_SUBPATH
-#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "unknown-linux"
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "unknown-"SPLS_LINUX
 # endif
 
 # include "uconfig.h"
@@ -215,6 +231,10 @@
 
 # define MZ_TCP_LISTEN_IPV6_ONLY_SOCKOPT
 
+# ifdef __ANDROID__
+#  define USE_FCNTL_O_NONBLOCK
+# endif
+
 # define FLAGS_ALREADY_SET
 
 #if defined(i386)
@@ -229,6 +249,12 @@
 #if defined(powerpc)
 # define MZ_USE_JIT_PPC
 #endif
+# if defined(__arm__)
+# define MZ_USE_JIT_ARM
+# ifndef __ANDROID__
+#  define MZ_USE_DWARF_LIBUNWIND
+# endif
+#endif
 
 #endif
 
@@ -287,12 +313,24 @@
   /************** x86/OpenBSD with gcc ****************/
               /* Thanks to Bengt Kleberg */
 
-#if defined(__OpenBSD__) && (defined(__i386__) || defined(i386) || defined(__x86_64__))
+#if defined(__OpenBSD__)
 
 # if defined(__x86_64__)
 #  define SCHEME_PLATFORM_LIBRARY_SUBPATH "x86_64-openbsd"
-# else
+# elif defined(__i386__) || defined(i386)
 #  define SCHEME_PLATFORM_LIBRARY_SUBPATH "i386-openbsd"
+# elif defined(__mips64__)
+#  if defined(__MIPSEL__)
+#   define SCHEME_PLATFORM_LIBRARY_SUBPATH "mips64el-openbsd"
+#  else
+#   define SCHEME_PLATFORM_LIBRARY_SUBPATH "mips64-openbsd"
+#  endif
+# elif defined(__powerpc__)
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "ppc-openbsd"
+# elif defined(__hppa__)
+#  define SCHEME_PLATFORM_LIBRARY_SUBPATH "hppa-openbsd"
+# else
+#  error Unported platform.
 # endif
 
 # include "uconfig.h"
@@ -305,9 +343,7 @@
 # undef UNIX_STACK_MAXIMUM
 # define UNIX_STACK_MAXIMUM 4194304
 
-#ifndef __ELF__
 # define UNDERSCORE_DYNLOAD_SYMBOL_PREFIX
-#endif
 
 # define USE_DLOPEN_GLOBAL_BY_DEFAULT
 
@@ -322,17 +358,15 @@
 # define USE_TM_GMTOFF_FIELD
 # define USE_TM_ZONE_FIELD
 
-#if defined(__x86_64__)
-# define MZ_USE_JIT_X86_64
-# define MZ_JIT_USE_MPROTECT
-# define MZ_TRY_EXTFLONUMS
-#elif defined(__i386__)
-# define MZ_USE_JIT_I386
-# define MZ_JIT_USE_MPROTECT
-# define MZ_TRY_EXTFLONUMS
-#else
-# error Unported platform.
-#endif
+# if defined(__x86_64__)
+#  define MZ_USE_JIT_X86_64
+#  define MZ_JIT_USE_MPROTECT
+#  define MZ_TRY_EXTFLONUMS
+# elif defined(__i386__)
+#  define MZ_USE_JIT_I386
+#  define MZ_JIT_USE_MPROTECT
+#  define MZ_TRY_EXTFLONUMS
+# endif
 
 # define FLAGS_ALREADY_SET
 
@@ -391,6 +425,7 @@
 
 # define USE_TM_GMTOFF_FIELD
 # define USE_TM_ZONE_FIELD
+# define MAX_VALID_DATE_SECONDS_BITS 51
 
 # define MZ_JIT_USE_MPROTECT
 
@@ -401,7 +436,7 @@
   /************** SGI/IRIX with SGI cc ****************/
 
 #if  (defined(mips) || defined(__mips)) \
-     && !(defined(ultrix) || defined(__ultrix) || defined(linux))
+     && !(defined(ultrix) || defined(__ultrix) || defined(linux) || defined(__OpenBSD__))
 
 # define SCHEME_PLATFORM_LIBRARY_SUBPATH "mips-irix"
 
@@ -445,7 +480,8 @@
 
   /************** ALPHA/OSF1 with gcc ****************/
 
-# if (defined(__alpha) || defined(__alpha__)) && !defined(linux) && !defined(__NetBSD__)
+# if (defined(__alpha) || defined(__alpha__)) \
+    && !defined(linux) && !defined(__NetBSD__) && !defined(__OpenBSD__)
 
 # define SCHEME_PLATFORM_LIBRARY_SUBPATH "alpha-osf1"
 
@@ -558,9 +594,6 @@
 /* Default stack size is 1MB, but we try to read
    the actual size from the executable on startup: */
 # define WINDOWS_DEFAULT_STACK_SIZE 1048576
-# ifdef _WIN64
-#  define STACK_SAFETY_MARGIN 100000
-# endif
 
 # ifndef _WIN64
 #  define USE_MZ_SETJMP
@@ -1049,6 +1082,7 @@
 
 # define USE_TM_GMTOFF_FIELD
 # define USE_TM_ZONE_FIELD
+# define MAX_VALID_DATE_SECONDS_BITS 51
 
 # define MZ_JIT_USE_MPROTECT
 
@@ -1107,6 +1141,9 @@
 
  /* TIME_TYPE_IS_UNSIGNED converts time_t values as unsigned. */
 
+ /* MAX_VALID_DATE_SECONDS_BITS sets a maximum number of bits for
+    seconds to pass to localtime() ro gmtime(). */
+
  /* MIN_VALID_DATE_SECONDS sets a minimum vald time in seconds. */
 
  /* PROCESS_FUNCTION adds (process ...) and (system ...) functions */
@@ -1209,6 +1246,8 @@
     should be closed after performing a fork() for `process'
     and `system' calls. */
 
+ /* SUBPROCESS_USE_FORK1 uses fork1() instead of fork(). */
+
  /* USE_UNIX_SOCKETS_TCP means that the tcp- procedures can be implemented
     with the standard Unix socket functions. */
 
@@ -1494,7 +1533,8 @@
 
  /* STACK_SAFETY_MARGIN <X> sets the number of bytes that should be
      available on the stack for "safety" to <X>. Used only if
-     DO_STACK_CHECK is used. STACK_SAFETY_MARGIN defaults to 50000. */
+     DO_STACK_CHECK is used. STACK_SAFETY_MARGIN defaults to 50000
+     for a 32-bit platform, twice as much for a 64-bit platform. */
 
  /* UNIX_LIMIT_STACK <X> limits stack usage to <X> bytes. This may
      be necessary to avoid GC-setup traversal over too much memory
@@ -1587,9 +1627,14 @@
  /*    Miscellaneous    */
 /***********************/
 
- /* USE_MAP_ANON indicates that mmap should use BSD's MAP_ANON flag
+ /* USE_MAP_ANON indicates that mmap() should use BSD's MAP_ANON flag
     rather than trying to open /dev/zero */
 
+ /* PREFER_MMAP_LARGE_BLOCKS indicates that mmap() should be called with
+    large block sizes as much as possible, because the actual allocated
+    size for small requests (on the order of the page size) is much
+    larger than the request. */
+
  /* REGISTER_POOR_MACHINE guides a hand optimization that seems to
     be work best one way for Sparc machines, and better the other
     way for x86 machines. */
@@ -1662,6 +1707,10 @@
  /* WIN32S_HACK uses a special hack to implement threads under Win32s
     with some compilers. Obsolete. */
 
+ /* FFI_CALLBACK_NEED_INT_CLEAR indiates thet libffi callback results
+    that are smaller than an `int' should clear `int'-sized space
+    in the result area. */
+
 #endif  /* FLAGS_ALREADY_SET */
 
 /****** (END CONFIGURATION FLAG DESCRPTIONS AND DEFAULTS) *******/
